@@ -21,6 +21,8 @@ type DeployFlags struct {
 
 	AppChangesMaxToKeep int
 
+	DefaultLabelScopingRules bool
+
 	Logs            bool
 	LogsAll         bool
 	AppMetadataFile string
@@ -45,6 +47,9 @@ func (s *DeployFlags) Set(cmd *cobra.Command) {
 	cmd.Flags().BoolVar(&s.OverrideOwnershipOfExistingResources, "dangerous-override-ownership-of-existing-resources",
 		false, "Steal existing resources from another app")
 
+	cmd.Flags().BoolVar(&s.DefaultLabelScopingRules, "default-label-scoping-rules",
+		true, "Use default label scoping rules")
+
 	cmd.Flags().IntVar(&s.AppChangesMaxToKeep, "app-changes-max-to-keep", ctlapp.AppChangesMaxToKeepDefault, "Maximum number of app changes to keep")
 
 	cmd.Flags().BoolVar(&s.Logs, "logs", true, fmt.Sprintf("Show logs from Pods annotated as '%s'", deployLogsAnnKey))
